==> haskell-digest-0.0.1.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
key: digest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
license: BSD3
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
author: Eugene Kirpichov <ekirpichov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
abi: 75318f2d7d8ad37e9f1cb0f2532a3868
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-9121LWkuBzpL6dmPh4HfAu
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: digest
version: 0.0.1.2
id: digest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
key: digest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
license: BSD-3-Clause
copyright: (c) 2009 Eugene Kirpichov
maintainer: Eugene Kirpichov <ekirpichov@gmail.com>
author: Eugene Kirpichov <ekirpichov@gmail.com>
stability: provisional
synopsis: Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.
description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.
category: Cryptography
abi: 9a66e4d776cdc011586339c2a3d30a2a
exposed: True
exposed-modules:
    Data.Digest.Adler32 Data.Digest.CRC32
import-dirs: /usr/lib/ghc-8.4.2/site-local/digest-0.0.1.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/digest-0.0.1.2
hs-libraries: HSdigest-0.0.1.2-I31fG7Yb9KfF2Ii6LMYpjd
extra-libraries:
    z
includes:
    zlib.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html: /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
